==> haskell-polyparse-1.12-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
key: polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text
abi: b03fb0f46a7457ec550ff2a8d8593a68
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.2.1/site-local/polyparse-1.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/polyparse-1.12
hs-libraries: HSpolyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.12-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-8mKJaXtdEV4EFGuCY0PhtK
key: polyparse-1.12-8mKJaXtdEV4EFGuCY0PhtK
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text
abi: ff9914f8df42ecd391ca67eb2805fac5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.2.2/site-local/polyparse-1.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/polyparse-1.12
hs-libraries: HSpolyparse-1.12-8mKJaXtdEV4EFGuCY0PhtK
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
